#
# spec file for package ghc-microlens
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name microlens
Name:           ghc-%{pkg_name}
Version:        0.4.11.2
Release:        bp153.1.20
Summary:        A tiny lens library with no dependencies
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros

%description
This library is an extract from <http://hackage.haskell.org/package/lens lens>
(with no dependencies). It's not a toy lenses library, unsuitable for “real
world”, but merely a small one. It is compatible with lens, and should have
same performance. It also has better documentation.

There's a longer readme <https://github.com/monadfix/microlens#readme on
Github>. It has a migration guide for lens users, a description of other
packages in the family, a discussion of other lens libraries you could use
instead, and so on.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%changelog
* Wed Jan  1 2020 Peter Simons <psimons@suse.com>
- Extend the %%description.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Sat Jul  6 2019 psimons@suse.com
- Update microlens to version 0.4.11.2.
  [#] 0.4.11.2
  * Fixed compilation on GHC 8.8 (thanks to @vmchale).
* Fri Jun 21 2019 psimons@suse.com
- Update microlens to version 0.4.11.1.
  [#] 0.4.11.1
  * Reverted marking `Lens.Micro.Internal` as `Trustworthy`, see [#122](https://github.com/monadfix/microlens/issues/122).
* Wed Jun 19 2019 psimons@suse.com
- Update microlens to version 0.4.11.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/microlens-0.4.11/src/CHANGELOG.md
* Fri Dec 14 2018 Peter Simons <psimons@suse.com>
- Apply Jan Engelhardt's improvements to the description.
* Sun Nov  4 2018 psimons@suse.com
- Update microlens to version 0.4.10.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/microlens-0.4.10/src/CHANGELOG.md
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update microlens to version 0.4.9.1.
  * Reexported `<&>` from `Data.Functor` (on recent versions of `base`).
  * Added `<>~`.
  * Added fixities for `<%%~`, `<<%%~`, `<<.~`.
  * Fixed compilation on GHC 8.4.
  * Added `HasCallStack` for some partial functions.
* Tue Mar 14 2017 psimons@suse.com
- Update to version 0.4.8.0 with cabal2obs.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 0.4.7.0 revision 0 with cabal2obs.
* Mon Aug  1 2016 psimons@suse.com
- Update to version 0.4.6.0 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.4.5.0 revision 0 with cabal2obs.
* Sun Jul  3 2016 mimi.vx@gmail.com
- update to 0.4.5.0
  * Added <&> (which makes lens creation easier).
* Sun Jun 12 2016 mimi.vx@gmail.com
- update to 0.4.4.3
  * Fixed markup in the .cabal file.
  * Added descriptions of other packages to Lens.Micro.
* Sat Jun 11 2016 mimi.vx@gmail.com
- update to 0.4.4.2
  * More changes to make microlens-platform more prominent.
* Fri Jun 10 2016 mimi.vx@gmail.com
- update to 0.4.4.1
  * Pointed to microlens-platform in the synopsis.
* Tue May 24 2016 mimi.vx@gmail.com
- update to 0.4.4.0
  * Added mapAccumLOf.
* Thu May  5 2016 mimi.vx@gmail.com
- update to 0.4.3.0
  * Added ?~.
* Sun Apr 17 2016 mimi.vx@gmail.com
- package ghc-microlens updated by st2obs
* Mon Feb 22 2016 mimi.vx@gmail.com
- package ghc-microlens updated by st2obs
* Sat Feb 13 2016 mimi.vx@gmail.com
- ghc-microlens generated by st2obs scritpt
